@@ -42,7 +42,9 @@ $inf = 10**10**10;
 use overload
     '0+' =>  sub { $_[0]->{epoch} }, 
     '<=>' => sub { 
-        $_[2] ? ($_[1] <=> $_[0]{epoch}) : ($_[0]{epoch} <=> $_[1]) },
+        return 0 unless defined $_[1];
+        $_[2] ? ($_[1] <=> $_[0]{epoch}) : ($_[0]{epoch} <=> $_[1]) 
+    },
     '-' =>   sub { 
         $_[2] ? ($_[1]  -  $_[0]{epoch}) : ($_[0]{epoch}  -  $_[1]) },
     '+' =>   sub { $_[0]->{epoch} + $_[1] },
